.. _release_history:

Release and Version History
==============================================================================


x.y.z (Backlog)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

**Minor Improvements**

**Bugfixes**

**Miscellaneous**


0.2.1 (2025-01-05)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- Add support for Jira
- Add a lot more Confluence api methods.
- Add the following public API:
    - ``Confluence.get_child_pages``
    - ``Confluence.get_labels``
    - ``Confluence.get_pages``
    - ``Confluence.get_pages_for_label``
    - ``Jira.get_all_status_for_project``
    - ``Jira.get_all_users``
    - ``Jira.get_issue``
    - ``Jira.get_projects_paginated``
    - ``Jira.search_for_issues_using_jql_enhanced_search``


0.1.1 (2024-12-25)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- First release
- Add the following public API:
    - ``Confluence``
    - ``Confluence.get_page_by_id``
    - ``Confluence.get_pages_in_space``
    - ``Confluence.get_spaces``
